package zone.yue.jvtc.android.exp07

import android.content.Context
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Button
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TopAppBar
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import zone.yue.jvtc.android.exp07.ui.theme.Exp07Theme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent { Exp07Theme { App() } }
    }
}

@Preview
@Composable
@OptIn(ExperimentalMaterial3Api::class)
fun App() {
    val context = LocalContext.current
    var text by remember { mutableStateOf("") }
    var readText by remember { mutableStateOf("") }

    return Scaffold(topBar = { TopAppBar(title = { Text("文件读写") }) }) { paddingValue ->
        Column(
            modifier = Modifier
                .padding(paddingValue)
                .padding(8.dp)
        ) {
            TextField(
                value = text,
                onValueChange = { text = it },
                modifier = Modifier.fillMaxWidth(),
                maxLines = 3,
            )
            Button(
                onClick = {
                    context.openFileOutput("test.txt", Context.MODE_PRIVATE).use {
                        it.write(text.toByteArray())
                    }
                },
                modifier = Modifier.fillMaxWidth(),
            ) { Text("写入文件") }
            Button(
                onClick = {
                    context.openFileInput("test.txt").bufferedReader().useLines {
                        readText = it.fold("") { some, text -> "$some\n$text"}
                    }
                },
                modifier = Modifier.fillMaxWidth(),
            ) { Text("读取文件") }
            Text(readText)
        }
    }
}